MethodChannelFplinkFlutter class

Inheritance

Properties

eventChannel EventChannel
final
eventStream Stream<Map<String, dynamic>>
네이티브 이벤트를 수신할 스트림
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearIdentity() Future<void>
override
click(String url) Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIdentity(String? identity) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited