FplinkFlutterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FplinkFlutterPlatform
Implementers

Constructors

FplinkFlutterPlatform()
생성자: 보안 토큰을 사용하여 인스턴스 검증

Properties

eventStream Stream<Map<String, dynamic>>
네이티브 이벤트를 수신할 스트림
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearIdentity() Future<void>
click(String url) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIdentity(String? identity) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FplinkFlutterPlatform
플러그인의 기본 인스턴스
getter/setter pair